@@ -7,7 +7,7 @@ from dagster.core.events import DagsterEvent
 from dagster.core.execution.api import create_execution_plan, execute_plan
 from dagster.core.execution.context.system import SystemPipelineExecutionContext
 from dagster.core.execution.plan.plan import ExecutionPlan
-from dagster.core.execution.retries import Retries
+from dagster.core.execution.retries import RetryMode
 from dagster.core.instance import DagsterInstance
 from dagster.utils import frozentags, iterate_with_context
 
@@ -22,7 +22,8 @@ DASK_RESOURCE_REQUIREMENTS_KEY = "dagster-dask/resource_requirements"
             Selector(
                 {
                     "existing": Field(
-                        {"address": StringSource}, description="Connect to an existing scheduler.",
+                        {"address": StringSource},
+                        description="Connect to an existing scheduler.",
                     ),
                     "local": Field(
                         Permissive(), is_required=False, description="Local cluster configuration."
@@ -105,7 +106,13 @@ def dask_executor(init_context):
 
 
 def query_on_dask_worker(
-    dependencies, recon_pipeline, pipeline_run, run_config, step_keys, mode, instance_ref,
+    dependencies,
+    recon_pipeline,
+    pipeline_run,
+    run_config,
+    step_keys,
+    mode,
+    instance_ref,
 ):  # pylint: disable=unused-argument
     """Note that we need to pass "dependencies" to ensure Dask sequences futures during task
     scheduling, even though we do not use this argument within the function.
@@ -142,7 +149,7 @@ class DaskExecutor(Executor):
 
     @property
     def retries(self):
-        return Retries.disabled_mode()
+        return RetryMode.DISABLED
 
     def execute(self, pipeline_context, execution_plan):
         check.inst_param(pipeline_context, "pipeline_context", SystemPipelineExecutionContext)
@@ -160,7 +167,7 @@ class DaskExecutor(Executor):
 
         step_levels = execution_plan.get_steps_to_execute_by_level()
 
-        pipeline_name = pipeline_context.pipeline_def.name
+        pipeline_name = pipeline_context.pipeline_name
 
         instance = pipeline_context.instance
 
